@@ -15,27 +15,25 @@
 //!     D = 0b1000,
 //! }
 //!
-//! fn main() {
-//!     let a_b = Test::A | Test::B; // BitFlags<Test>
-//!     let a_c = Test::A | Test::C;
-//!     let b_c_d = Test::C | Test::B | Test::D;
+//! let a_b = Test::A | Test::B; // BitFlags<Test>
+//! let a_c = Test::A | Test::C;
+//! let b_c_d = Test::C | Test::B | Test::D;
 //!
-//!     // BitFlags<Test>(0b11, [A, B])
-//!     println!("{:?}", a_b);
+//! // BitFlags<Test>(0b11, [A, B])
+//! println!("{:?}", a_b);
 //!
-//!     // BitFlags<Test>(0b1, [A])
-//!     println!("{:?}", a_b & a_c);
+//! // BitFlags<Test>(0b1, [A])
+//! println!("{:?}", a_b & a_c);
 //!
-//!     // Iterate over the flags like a normal set!
-//!     assert_eq!(a_b.iter().collect::<Vec<_>>(), &[Test::A, Test::B]);
+//! // Iterate over the flags like a normal set!
+//! assert_eq!(a_b.iter().collect::<Vec<_>>(), &[Test::A, Test::B]);
 //!
-//!     assert!(a_b.contains(Test::A));
-//!     assert!(b_c_d.contains(Test::B | Test::C));
-//!     assert!(!(b_c_d.contains(a_b)));
+//! assert!(a_b.contains(Test::A));
+//! assert!(b_c_d.contains(Test::B | Test::C));
+//! assert!(!(b_c_d.contains(a_b)));
 //!
-//!     assert!(a_b.intersects(a_c));
-//!     assert!(!(a_b.intersects(Test::C | Test::D)));
-//! }
+//! assert!(a_b.intersects(a_c));
+//! assert!(!(a_b.intersects(Test::C | Test::D)));
 //! ```
 //!
 //! ## Note
@@ -186,7 +184,15 @@ impl<T> BitFlags<T>
 where
     T: RawBitFlags,
 {
-    /// Create a new BitFlags unsafely. Consider using `from_bits` or `from_bits_truncate`.
+    /// Create a new BitFlags unsafely, without checking if the bits form
+    /// a valid bit pattern for the type.
+    ///
+    /// Consider using `from_bits` or `from_bits_truncate` instead.
+    ///
+    /// # Safety
+    ///
+    /// The argument must not have set bits at positions not corresponding to
+    /// any flag.
     pub unsafe fn new(val: T::Type) -> Self {
         BitFlags { val }
     }
@@ -386,10 +392,10 @@ mod impl_serde {
         fn deserialize<D: serde::Deserializer<'a>>(d: D) -> Result<Self, D::Error> {
             let val = T::Type::deserialize(d)?;
             Self::from_bits(val)
-                .ok_or_else(|| D::Error::invalid_value(
+                .or_else(|_| Err(D::Error::invalid_value(
                     Unexpected::Unsigned(val.into()),
                     &"valid bit representation"
-                ))
+                )))
         }
     }
 
